@@ -3,9 +3,9 @@ package App::ThisMod;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-05'; # DATE
+our $DATE = '2022-08-21'; # DATE
 our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 1;
 # ABSTRACT: Synonym for App::ThisDist
@@ -22,7 +22,7 @@ App::ThisMod - Synonym for App::ThisDist
 
 =head1 VERSION
 
-This document describes version 0.016 of App::ThisMod (from Perl distribution App-ThisDist), released on 2022-06-05.
+This document describes version 0.017 of App::ThisMod (from Perl distribution App-ThisDist), released on 2022-08-21.
 
 =head1 DESCRIPTION
 
@@ -57,9 +57,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
